# MyApp

A simple command-line Python application that prints a description of a person.

## 🧑 What It Does

When you run the command:

```bash
myapp


Use cd: + file path to go to a specific file directory

Use pip install -e . from myApp directory to be able to run this program 
with just the terminal command: myApp 